'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _variable = require('./variable');

var _variable2 = _interopRequireDefault(_variable);

var _hooks = require('./hooks');

var _hooks2 = _interopRequireDefault(_hooks);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function () {
  let options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return input => {
    return function istanbulThresholds() /* log */{
      const createCoverageMap = require('istanbul-lib-coverage').createCoverageMap;
      const createSourceMapStore = require('istanbul-lib-source-maps').createSourceMapStore;
      const libCoverage = require('istanbul-lib-coverage');

      return new Promise((resolve, reject) => {
        _hooks2.default.clearAll();

        if (!global[_variable2.default]) {
          return reject('no coverage information was collected');
        }

        const coverageMap = createCoverageMap(global[_variable2.default]);
        const sourceMapStore = createSourceMapStore();
        const remappedCoverageMap = sourceMapStore.transformCoverage(coverageMap);
        const coverageSummary = libCoverage.createCoverageSummary();

        remappedCoverageMap.files().forEach(file => {
          const fileCoverage = remappedCoverageMap.fileCoverageFor(file);
          const fileSummary = fileCoverage.toSummary();

          coverageSummary.merge(fileSummary);
        });

        const result = Object.keys(options).reduce((errors, key) => {
          const threshold = options[key];
          const summary = coverageSummary[key];

          // check percentage threshold
          if (threshold > 0) {
            if (summary.pct < threshold) {
              return errors.concat(`${ key } percentage: ${ summary.pct }% < ${ threshold }%`);
            }
          }

          // check gap threshold
          if (threshold < 0) {
            if (summary.covered - summary.total < threshold) {
              return errors.concat(`${ key } gap: ${ summary.covered } - ${ summary.total } < ${ threshold }`);
            }
          }

          return errors;
        }, []);

        if (result.length > 0) {
          return reject(result);
        }

        resolve(input);
      });
    };
  };
};